<?php
namespace Bushelpowered\Api\Reporting\Contracts\V1;

use \Bushelpowered\Api\Common\Request\SlugRequest;
use \Bushelpowered\Api\Reporting\Contracts\V1\Response\ExportConfigResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\ConstraintViolation;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bushelpowered\Api\Common\NotFound;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetExportConfigBySlug 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(SlugRequest $request, $headers): ExportConfigResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError
    {
         return $this->client->call('api/reporting/contracts/v1/GetExportConfigBySlug', $request, $this->getWrapper(), $headers);
    }
    
    private function getWrapper() {
        return new class () implements \Bidl\Php\Core\BidlResponse {

            /** @var ExportConfigResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError */
            public $response;
        
            public function __construct()
            {
                $this->mapper = new \JsonMapper();
            }
            
            public function fromJson($data) 
            {
                switch($data->type) {
                  case 'api.reporting.contracts.v1#GetExportConfigBySlugSuccess':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Reporting\Contracts\V1\Response\ExportConfigResponse::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#BadRequest':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#ConstraintViolation':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\ConstraintViolation::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthenticated':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotAuthorized':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                  case 'api.common#NotFound':
                    $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotFound::class))->newInstanceWithoutConstructor();
                    $this->response = $this->mapper->map($data, $empty);
                    break;
                   default: 
                     $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
                }
            }
        };
    }
}